<script setup>
import AppLayout from '@/Layouts/AppLayoutWater.vue';
import Welcome from '@/Jetstream/Welcome.vue';
import { Head, Link, useForm } from '@inertiajs/inertia-vue3';
import mapboxgl from 'mapbox-gl';
import 'mapbox-gl/dist/mapbox-gl.css';
import JetButton from '@/Jetstream/Button.vue';
import DK_Input from '@/components/dk_Input.vue';
import JetModal from '@/Jetstream/Modal.vue';
import VueMultiselect from 'vue-multiselect';
import DK_Button from '@/components/dk_Button.vue';

</script>

<style>
table {
    border-color: transparent !important;
}

.dataTables_wrapper {
    margin-bottom: 0.5rem !important;
}

.dataTables_wrapper .dataTables_paginate .paginate_button.disabled,
.dataTables_wrapper .dataTables_paginate .paginate_button.disabled:hover,
.dataTables_wrapper .dataTables_paginate .paginate_button.disabled:active {
    cursor: default;
    color: rgba(200, 200, 200, 0.9) !important;
    border: 1px solid transparent;
    background: transparent;
    box-shadow: none;
}

.dataTables_wrapper .dataTables_paginate .paginate_button {
    box-sizing: border-box;
    display: inline-block;
    min-width: 1.5em;
    padding: 0.5em 1em;
    margin-left: 2px;
    text-align: center;
    text-decoration: none !important;
    cursor: pointer;
    cursor: hand;
    color: rgba(200, 200, 200, 0.9) !important;
    border: 0;
    border-radius: 0.375rem;
}

.dataTables_wrapper .dataTables_paginate .paginate_button:hover {
    color: rgba(200, 200, 200, 1) !important;
    background-color: rgba(0, 152, 219, 0.1) !important;
    background-image: unset !important;
    border: 0;
}

.dataTables_wrapper .dataTables_paginate .paginate_button.current,
.dataTables_wrapper .dataTables_paginate .paginate_button.current:hover {
    color: rgba(255, 250, 250, 1) !important;
    border: 0 !important;
    background-color: rgba(0, 152, 219, 0.2) !important;
    background-image: unset !important;
    border-bottom-width: 2px;
    border-bottom-color: rgba(255, 250, 250, 1);
    border-radius: 0.375rem;
}

.dataTable thead th,
.dataTable thead td {
    padding-top: 0 !important;
    padding-bottom: 0 !important;
}

table.dataTable thead th,
table.dataTable thead td {
    padding: 0px 10px;
    font-size: 0.9rem !important;
    border-bottom: 1px solid rgba(200, 200, 200, 0.75) !important;
}

textarea::-webkit-input-placeholder {
    color: rgba(200, 200, 200, 0.75) !important;
}

textarea:-moz-placeholder {
    /* Firefox 18- */
    color: rgba(200, 200, 200, 0.75) !important;
}

textarea::-moz-placeholder {
    /* Firefox 19+ */
    color: rgba(200, 200, 200, 0.75) !important;
}

textarea:-ms-input-placeholder {
    color: rgba(200, 200, 200, 0.75) !important;
}

textarea::placeholder {
    color: rgba(200, 200, 200, 0.75) !important;
}

input::placeholder {
    color: rgba(200, 200, 200, 0.75) !important;
}
</style>

<template>
    <AppLayout title="Devices">
        <div style="height: calc(100vh - 4.75rem);"
            class="bg-darkblue-background z-0 cursor-default text-gray-light overflow-y-scroll select-none" v-bind:class="{'p-8 ' : this.screen_width >= 768, 'pt-2 pb-4 px-3' : this.screen_width < 768}">

            <div class="grid grid-cols-8 " v-bind:class="{'gap-8' : this.screen_width >= 768, 'gap-2' : this.screen_width < 768}">

                <div v-if="this.screen_width >= 768" class="inline-flex justify-between col-span-8 2xl:col-span-6 2xl:col-start-2 row-start-1">
                    <!--<p class="text-white-snow text-2xl">{{ this.$t("water." + "manageNetworkLang") }}</p>-->
                    <p class="text-white-snow font-light text-center text-2xl">{{ this.$t("water." + "manageNetworkLang") }} </p>
                    <div class="flex justify-center items-center gap-2">

                        <DK_Button color="blue" :fixedSize="true" v-if="!EditionMode" v-on:click="this.ChangeEditionMode()">
                            {{ this.$t("general.Edit") }}
                        </DK_Button>

                        <DK_Button color="blue" :fixedSize="true" v-else v-on:click="this.ChangeEditionMode()">
                            {{ this.$t("general.Cancel") }}
                        </DK_Button>

                        <DK_Button color="blue" :fixedSize="true" onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit'); window.history.go(-1)">
                            {{ this.$t("general.Back") }}
                        </DK_Button>
                    </div>
                </div>

                <div v-else class="w-full flex flex-row justify-between items-center h-[3.25rem] col-span-8">
                    <div class="w-full flex flex-col justify-start">
                        <div class="flex flex-row justify-start">
                            <p class="text-white-snow font-light text-2xl text-left">{{ this.$t('water.manageNetworkLang') }}</p>
                        </div>
                    </div>
                    <div class="flex justify-end gap-2">
                        <div class="flex items-center justify-center" v-if="!EditionMode" v-on:click="this.ChangeEditionMode()">
                            <button type="button" class="text-white-snow button-blue font-medium rounded-lg text-sm p-[7px] text-center inline-flex items-center">
                                <i class="fa-solid fa-pen-to-square" style="font-size:0.75rem; color:#FFFAFA;"></i>
                            </button>
                        </div>
                        <div class="flex items-center justify-center" v-else v-on:click="this.ChangeEditionMode()">
                            <button type="button" class="text-white-snow button-blue font-medium rounded-lg text-sm px-[9.25px] py-[7px] text-center inline-flex items-center">
                                <i class="fa-solid fa-xmark" style="font-size:0.75rem; color:#FFFAFA;"></i>
                            </button>
                        </div>
                        <div class="flex items-center justify-center">
                            <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit'); window.history.go(-1)">
                                <button type="button" class="text-white-snow button-blue font-medium rounded-lg text-sm p-1.5 text-center inline-flex items-center">
                                    <i class="fa-solid fa-arrow-left" style="font-size:0.75rem; color:#FFFAFA;"></i>
                                </button>
                            </Link>
                        </div>
                    </div>
                </div>

                <div class="col-span-8 2xl:col-span-6 col-start-1 2xl:col-start-2">
                    <div v-bind:class="{'p-4' : this.screen_width >= 768, 'p-2' : this.screen_width < 768}" class="baltoro-container  grid grid-cols-6 gap-6">
                        <div class="flex flex-col justify-start" v-bind:class="{'col-span-2 mr-3' : this.screen_width >= 768, 'col-span-6' : this.screen_width < 768}">
                            
                            <p class="mt-3 font-light text-center text-white-snow text-xl 2xl:mb-4 mb-1" v-if="this.screen_width >= 768">
                                {{ this.$t("general." + "Name") }}
                            </p>

                            <p v-else class="text-md text-left text-cyan-text font-light whitespace-nowrap">
                                {{ this.$t("general." + "Name") }}
                            </p>

                            <textarea v-if="EditionMode && false" v-on:keyup="this.SetNameButtons()" id="id_name"
                                oninput="this.style.height = ''; this.style.height = this.scrollHeight + 'px'" type="text"
                                class="modal-input px-2 py-1 text-sm" :placeholder="temporal_name" />
                            <p v-else class="modal-input-2 px-2 py-1 text-sm text-center">
                                {{ temporal_name }}
                            </p>

                            <div v-if="EditionMode && false" class="flex justify-end gap-4 mt-4 pr-0.5">

                                <DK_Button color="blue" :fixedSize="true" v-on:click="this.SaveEditName()">
                                    {{ this.$t("general.Update") }}
                                </DK_Button>

                            </div>
                        </div>
                        <div class="flex flex-col justify-start" v-bind:class="{'col-span-4' : this.screen_width >= 768, 'col-span-6' : this.screen_width < 768}">

                            <p class="mt-3 font-light text-center text-white-snow text-xl 2xl:mb-4 mb-1" v-if="this.screen_width >= 768">
                                {{ this.$t("general." + "Description") }}
                            </p>                            

                            <p v-else class="text-md text-left text-cyan-text font-light whitespace-nowrap">
                                {{ this.$t("general." + "Description") }}
                            </p>

                            <textarea v-if="EditionMode" v-on:keyup="this.SetDescriptionButtons()" id="id_description"
                                oninput="this.style.height = ''; this.style.height = this.scrollHeight + 'px'" type="text"
                                class="modal-input px-2 py-1 text-sm" :placeholder="temporal_description" />
                            <p v-else class="modal-input-2 px-2 py-1 text-sm text-center">
                                {{ temporal_description }}
                            </p>

                            <div v-if="EditionMode" class="flex justify-end gap-4 pr-0.5" v-bind:class="{'mt-4' : this.screen_width >= 768, 'mt-2' : this.screen_width < 768}">

                                <DK_Button color="blue" :fixedSize="true" v-on:click="this.SaveEditDescription()">
                                    {{ this.$t("general.Update") }}
                                </DK_Button>

                            </div>
                        </div>
                    </div>
                </div>

                <!--<div class="baltoro-container col-span-2 col-start-1 2xl:col-start-2 py-4 row-start-3">

                    <p class="mt-3 font-light text-center text-white-snow text-xl 2xl:mb-4 mb-1">
                        {{ this.$t("general." + "Location") }}</p>

                    <div v-if="!EditionMode" class="2xl:h-[3px] h-[2.7px]"></div>

                    <div class="h-48" id="map" />

                    <div class="grid grid-rows-2 pt-2 px-3">
                        <div class="flex row-span-1 justify-between text-md text-white-snow font-light"
                            v-bind:class="{ 'mt-[4.5px]': EditionMode }">
                            <p class="text-left text-cyan-text">{{ this.$t("general." + "Latitude") }}</p>
                            <div v-if="EditionMode" class="flex justify-end items-center">
                                <DK_Input id="id_lat" type="text" v-on:keyup="this.SetLatLngButtons()" :placeholder="parseFloat(temporal_lat).toFixed(6)" :border="true" textPosition="center" width="full"/>
                            </div>
                            <p v-else class="modal-input-nb text-right">
                                {{ parseFloat(temporal_lat).toFixed(6) }}
                            </p>
                        </div>

                        <div class="flex row-span-1 justify-between text-md text-white-snow font-light"
                            v-bind:class="{ 'mt-[4.5px]': EditionMode }">
                            <p class="text-left text-cyan-text">{{ this.$t("general." + "Longitude") }}</p>
                            <div v-if="EditionMode" class="flex justify-end items-center">
                                <DK_Input id="id_lng" type="text" v-on:keyup="this.SetLatLngButtons()" :placeholder="parseFloat(temporal_lng).toFixed(6)" :border="true" textPosition="center" width="full"/>
                            </div>
                            <p v-else class="modal-input-nb text-right">
                                {{ parseFloat(temporal_lng).toFixed(6) }}
                            </p>
                        </div>
                    </div>

                    <div v-if="EditionMode" class="flex justify-end gap-4 mt-8 pr-0.5 mr-3">
                        
                        <DK_Button color="blue" :fixedSize="true" v-on:click="this.SaveEditLatLng()">
                            {{ this.$t("general.Update") }}
                        </DK_Button>

                    </div>
                </div>-->

                <div v-bind:class="{'col-span-4 2xl:col-span-3 2xl:col-start-2 row-span-2 col-start-1 row-start-3' : this.screen_width >= 768, 'col-span-8' : this.screen_width < 768}">

                    <div v-bind:class="{'p-4' : this.screen_width >= 768, 'p-2' : this.screen_width < 768}" class="baltoro-container  flex flex-col justify-start">

                        <p v-if="!AddSector && this.screen_width >= 768" class="mt-3 font-light text-center text-white-snow text-xl 2xl:mb-4 mb-1">
                            {{ this.$t("general." + "Sectorization") }}
                        </p>   

                        <p v-else-if="AddSector && this.screen_width >= 768" class="mt-3 font-light text-center text-white-snow text-xl 2xl:mb-4 mb-1">
                            {{ this.$t("general." + "Creating Sector") }}
                        </p>

                        <div v-bind:class="{ 'invisible': AddSector, 'mt-4': EditionMode, 'justify-between': EditionMode, ' px-8 ' : this.screen_width >= 768 }"
                            class="w-full inline-flex justify-center mt-[8px] mb-[8px]">

                            <!--<select class="modal-input-select pb-[3px] cursor-pointer" style="width:50%" id="id_sector_selector" name="sector">
                                    <option v-for="(sector, index) in this.data.group_sector" :key="sector.id" class="bg-darkblue-opa-container cursor-pointer" :value="index">{{sector.name}}</option>
                                </select>-->
                            <div class="w-1/2 text-center">

                                <VueMultiselect id="id_sector_selector" v-model=this.value_selector
                                    :options=this.data.group_sector :multiple="false" :close-on-select="true" label="name"
                                    track-by="id" :hide-selected="true" @select="selectItem" @remove="removeItem"
                                    @input="inputMultiselect" @search-change="scMultiselect" @tag="tagItem"
                                    @open="openMultiselect" @close="closeMultiselect" />

                            </div>


                            <div v-if="EditionMode" class="flex justify-center items-center">

                                <DK_Button color="blue" :fixedSize="true" v-on:click="this.showCreateSector()">
                                    {{ this.$t("general.Create") }}
                                </DK_Button>

                            </div>
                        </div>

                        <div v-if="this.screen_width >= 768" class="border-t border-gray-medium mx-10 mt-[26px] pb-[11px]"></div>

                        <div v-else class="border-t border-gray-medium mt-[11px] pb-[11px]"></div>

                        <div class="grid grid-cols-3 gap-x-8 font-light text-gray-light text-center" 
                            v-bind:class="{'px-8 py-4 gap-y-4 ' : this.screen_width >= 768,}">
                            <div class="col-span-2">
                                <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Name") }}</p>
                                <DK_Input v-if="EditionMode" v-on:keyup="this.SetSectorButtons()" id="id_sector_name" type="text" :placeholder="temporal_sector_name" :border="true" textPosition="center" width="full"/>
                                <p v-else class="modal-input-2 text-center">
                                    {{ temporal_sector_name }}
                                </p>
                            </div>

                            <div class="col-span-1">
                                <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Tag") }}</p>
                                <DK_Input v-if="EditionMode" v-on:keyup="this.SetSectorButtons()" id="id_sector_tag" type="text" :placeholder="temporal_sector_tag" :border="true" textPosition="center" width="full"/>
                                <p v-else class="modal-input-2 text-center">
                                    {{ temporal_sector_tag }}
                                </p>
                            </div>

                            <div class="col-span-3  mt-[14px]">
                                <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Description") }}</p>
                                <DK_Input v-if="EditionMode" v-on:keyup="this.SetSectorButtons()" id="id_sector_description" type="text" :placeholder="temporal_sector_description" :border="true" textPosition="center" :textarea="true" width="full"/>
                                <p v-else class="modal-input-2 px-2 py-1 text-sm min-h-[30px]">
                                    {{ temporal_sector_description }}
                                </p>
                            </div>
                        </div>

                        <div v-if="EditionMode" class="flex justify-end col-span-10 gap-4 pr-0.5 mt-1" v-bind:class="{'mt-2' : this.screen_width >= 768,}">

                            <DK_Button color="blue" :fixedSize="true" v-if="!AddSector" v-on:click="this.SaveEditSector(this.temporal_sector_id)">
                                {{ this.$t("general.Update") }}
                            </DK_Button>

                            <DK_Button color="blue" :fixedSize="true" v-if="AddSector" v-on:click="this.SaveCreateSector()">
                                {{ this.$t("general.Create") }}
                            </DK_Button>

                            <DK_Button color="blue" :fixedSize="true" v-if="AddSector" v-on:click="this.CancelEditSector()">
                                {{ this.$t("general.Cancel") }}
                            </DK_Button>

                            <DK_Button color="red" :fixedSize="true" v-if="!AddSector" v-on:click="this.openDelete(false, 'sector')">
                                {{ this.$t("general.Delete") }}
                            </DK_Button>

                        </div>
                    </div>
                </div>

                <div v-bind:class="{'col-span-4 2xl:col-span-3 2xl:col-start-5 row-span-2 col-start-5 row-start-3' : this.screen_width >= 768, 'col-span-8' : this.screen_width < 768}">

                    <div v-bind:class="{'p-4' : this.screen_width >= 768, 'p-2' : this.screen_width < 768}" class="baltoro-container  flex flex-col justify-start">
                        
                        <p v-if="!AddSector && this.screen_width >= 768" class="mt-3 font-light text-center text-white-snow text-xl 2xl:mb-4 mb-1">
                            {{ this.$t("general." + "Services") }}
                        </p>   

                        <p v-else-if="AddSector && this.screen_width >= 768" class="mt-3 font-light text-center text-white-snow text-xl 2xl:mb-4 mb-1">
                            {{ this.$t("general." + "Creating Service") }}
                        </p>

                        <div v-bind:class="{ 'justify-between': EditionMode, 'invisible': AddService, 'pt-2' : this.screen_width < 768, 'px-8' : this.screen_width >= 768 }"
                            class="w-full inline-flex justify-center">
                            <div class="grid grid-rows-2 gap-y-1"
                                v-bind:class="{
                                    'grid-cols-6': this.data.group_service.length < 7,
                                    'grid-cols-8': this.data.group_service.length < 9 && this.data.group_service.length > 6,
                                    'grid-cols-10': this.data.group_service.length < 11 && this.data.group_service.length > 8
                                }">

                                <div v-if="this.data.group_service.length % 2 == 1"
                                    class="col-start-1 row-start-2 col-span-1 row-span-1"></div>

                                <div v-for="(data_g, index_g) in this.data.group_service" :key="index_g"
                                    v-on:click='this.SetService(index_g)'
                                    class="inline-flex rounded-md text-white-snow font-light text-base col-span-2 cursor-pointer"
                                    v-bind:class='{ "opacity-40": data_g.name != temporal_service_name }'>
                                    <p :style="{ 'background-color': data_g.color }" class="service-label mx-0.5">
                                        {{ data_g.tag }}
                                    </p>
                                </div>
                            </div>
                            <div v-if="EditionMode" class="flex justify-center items-center">

                                <DK_Button class="opacity-50 pointer-events-none" color="blue" :fixedSize="true" v-on:click="this.showCreateService()">
                                    {{ this.$t("general.Create") }}
                                </DK_Button>

                                <DK_Button color="blue" :fixedSize="true" v-if="AddSector" v-on:click="this.CancelEditSector()">
                                    {{ this.$t("general.Cancel") }}
                                </DK_Button>

                            </div>

                        </div>

                        <div v-if="!this.EditionMode && this.screen_width >= 768" class="border-t border-gray-medium mx-10 mt-[26px] pb-[11px]"></div>

                        <div v-else-if="this.screen_width >= 768" class="border-t border-gray-medium mx-10 mt-[30px] pb-[11px]"></div>

                        <div v-else class="border-t border-gray-medium mt-[11px] pb-[11px]"></div>

                        <div class="grid grid-cols-3 gap-x-8 font-light text-gray-light text-center" v-bind:class="{'py-4 px-8 gap-y-4 ' : this.screen_width >= 768}">
                            <div class="col-span-2">
                                <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Name") }}</p>
                                <DK_Input id="id_service_name" :placeholder="temporal_service_name" v-on:keyup="this.SetServiceButtons()" width="full" v-if="AddService || (temporal_service_block.indexOf(temporal_service_id) == -1 && EditionMode)" type="text"></DK_Input>
                                <p v-else class="modal-input-2">{{ temporal_service_name.length != 0 ? temporal_service_name : '' }}</p>
                            </div>

                            <div class="col-span-1">
                                <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Tag") }}</p>
                                <DK_Input id="id_service_tag" :placeholder="temporal_service_tag" v-on:keyup="this.SetServiceButtons()" width="full" v-if="AddService || (temporal_service_block.indexOf(temporal_service_id) == -1 && EditionMode)" type="text"></DK_Input>
                                <p v-else class="modal-input-2">{{ temporal_service_tag }}</p>
                            </div>

                            <div class="col-span-3 mt-[14px]">
                                <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Description") }}</p>
                                <DK_Input v-if="AddService || (temporal_service_block.indexOf(temporal_service_id) == -1 && EditionMode)" v-on:keyup="this.SetServiceButtons()" id="id_service_description" type="text" :placeholder="temporal_service_description" :border="true" textPosition="center" :textarea="true" width="full"/>
                                <p v-else class="modal-input-2 text-sm py-1 px-2"
                                    v-bind:class="{ 'h-[50px] mb-[0.375rem]': AddService && temporal_service_block.indexOf(temporal_service_id) != -1 }">
                                    {{ temporal_service_description }}</p>
                            </div>
                        </div>

                        <div v-if="EditionMode" class="flex justify-end col-span-10 gap-4 mt-4 pr-0.5"
                            v-bind:class='{ "hidden": temporal_service_block.indexOf(temporal_service_id) != -1 } && AddService'>

                            <DK_Button color="blue" :fixedSize="true" v-on:click="this.SaveEditService(this.temporal_service_id)" v-if="!AddService && temporal_service_block.indexOf(temporal_service_id) == -1">
                                {{ this.$t("general.Update") }}
                            </DK_Button>

                            <DK_Button class="opacity-50 pointer-events-none" color="blue" :fixedSize="true" v-on:click="this.SaveCreateService()" v-if="AddService">
                                {{ this.$t("general.Create") }}
                            </DK_Button>

                            <DK_Button color="blue" :fixedSize="true" v-on:click="this.CancelEditService()" v-if="AddService">
                                {{ this.$t("general.Cancel") }}
                            </DK_Button>

                            <DK_Button color="red" :fixedSize="true" v-on:click="this.openDelete(false, 'service')" v-if="!AddService && temporal_service_block.indexOf(temporal_service_id) == -1">
                                {{ this.$t("general.Delete") }}
                            </DK_Button>

                        </div>
                    </div>
                </div>
            </div>
        </div>

        <JetModal :show="this.DeleteModal" :closeable="false">

            <p class="mt-3 font-light text-center text-white-snow text-xl">{{ this.$t("text." + "Are you sure?") }}</p>

            <p class="mt-3 font-light text-center text-gray-light px-4">{{ this.$t("text." + "Once deleted, there will be no way to retrieve it")}}</p>

            <div class="grid grid-cols-10 gap-x-8 px-8 py-4 gap-y-4 font-light text-gray-light text-center">

                <div class="flex justify-center col-span-10 gap-4 mt-4">

                    <DK_Button color="blue" :fixedSize="true" v-on:click="this.closeDelete()">
                        {{ this.$t("general.Keep") }}
                    </DK_Button>

                    <DK_Button color="red" :fixedSize="true" v-on:click="this.openDelete(true, temporal_selector)">
                        {{ this.$t("general.Delete") }}
                    </DK_Button>

                </div>
            </div>
        </JetModal>

    </AppLayout>
</template>

<script>
export default {

    data() {
        return {
            Back: localStorage.getItem('Back'),
            temporal_lat: this.device_group[0].GPS_lat,
            temporal_lng: this.device_group[0].GPS_lng,
            temporal_sector_name: this.data.group_sector[0].name,
            temporal_sector_tag: this.data.group_sector[0].tag,
            temporal_sector_description: this.data.group_sector[0].description,
            temporal_sector_id: this.data.group_sector[0].id,
            temporal_service_name: this.data.group_service[0].name,
            temporal_service_tag: this.data.group_service[0].tag,
            temporal_service_description: this.data.group_service[0].description,
            temporal_service_id: 0,
            temporal_name: this.device_group[0].name,
            temporal_description: this.device_group[0].description,
            temporal_service_block: [0, 1, 2, 3, 4],
            temporal_selector: null,
            show_name_buttons: false,
            show_description_buttons: false,
            show_latlng_buttons: false,
            show_sector_buttons: false,
            show_service_buttons: false,
            DeleteModal: false,
            AddSector: false,
            AddService: false,
            EditionMode: false,
            screen_width: 0,
            value_selector: this.data.group_sector[0],
        }
    },
    props: ['device_group', 'data', 'user'],

    beforeCreate: function () {
        this.$i18n.locale = this.user.language
    },

    beforeMount() {
        this.screen_width = window.screen.width;
    },

    mounted() {
        window.emitter.emit('changeLoaderStatus', false, 'orbit')

        // MAPBOX ACCESS TOKEN
        mapboxgl.accessToken = 'pk.eyJ1IjoiZGF0YWtvcnVtLWRldmVsb3AiLCJhIjoiY2w0ODhqOXc2MDR1MjNjbzJ2YnZkdjNhYSJ9.pVPMnmkwOuF4DonlbNkkEw';

        // creating map
        /*const map = new mapboxgl.Map({
            attributionControl: false,
            container: "map",
            style: 'mapbox://styles/datakorum-develop/cl4cu370w000v15tal53sxn9v',
            center: [this.temporal_lng, this.temporal_lat],
            zoom: 10,
            pitch: 67.5,
            bearing: 0,
            interactive: false
        });

        new mapboxgl.Marker({ color: 'rgba(5, 255, 243, 0.75)' })
            .setLngLat([this.temporal_lng, this.temporal_lat])
            .addTo(map);*/

        document.getElementById('id_sector_selector').addEventListener("change", () => { this.SetSector(document.getElementById("id_sector_selector").value) });

    },

    methods: {
        ChangeEditionMode() {
            this.EditionMode = !(this.EditionMode);

            if (!this.EditionMode) {
                //this.CancelEditName()
                this.CancelEditDescription()
                //this.CancelEditLatLng()
            }
        },
        SaveEditName() {
            var name;
            if (document.getElementById('id_name').value != '') {
                name = document.getElementById('id_name').value;
            } else {
                name = this.temporal_name;
            }

            /*var description;
            if(document.getElementById('id_description').value!=''){
                description = document.getElementById('id_description').value;
            }else{                
                description = this.temporal_description;
            }

            var description = this.temporal_description;
            var lat = this.temporal_lat;
            var lng = this.temporal_lng;

            */

        },
        CancelEditName() {
            document.getElementById('id_name').value = '';
            this.show_name_buttons = false;
        },
        SaveEditDescription() {
            var description;
            if (document.getElementById('id_description').value != '') {
                description = document.getElementById('id_description').value;
            } else {
                description = this.temporal_description;
            }

            var lat = this.temporal_lat;
            var lng = this.temporal_lng;

            const data = {
                description: description,
                lat: lat,
                lng: lng,
            };

            window.emitter.emit('changeLoaderStatus', true, 'orbit')

            axios({
                method: 'put',
                url: window.location.origin + '/api/group/group_info/' + this.user.id + '/' + this.device_group[0].id,
                headers: {
                    'Accept': 'application/json',
                    'Content-Type': 'application/json',
                    'Authorization': 'Bearer ' + this.user.token
                },
                data: data
            })
                .then((response) => {
                    this.temporal_description = data.description
                    this.temporal_lat = data.lat
                    this.temporal_lng = data.lng

                    location.reload(true);
                })
                .catch((error) => {
                    window.emitter.emit('changeLoaderStatus', false, 'orbit')

                    if(error.response && error.response.status && error.response.status == 429){
                    window.alert( this.$t('text.Api attempts'));
                    }else{
                    return "Failed!", error;
                    }

                });
        },
        CancelEditDescription() {
            document.getElementById('id_description').value = '';
            this.show_description_buttons = false;
        },
        SaveEditLatLng() {
            var lat;
            if (document.getElementById('id_lat').value != '') {
                lat = document.getElementById('id_lat').value;
            } else {
                lat = this.temporal_lat;
            }

            var lng;
            if (document.getElementById('id_lng').value != '') {
                lng = document.getElementById('id_lng').value;
            } else {
                lng = this.temporal_lng;
            }

            var description = this.temporal_description;

            const data = {
                description: description,
                lat: lat,
                lng: lng,
            };

            window.emitter.emit('changeLoaderStatus', true, 'orbit')

            axios({
                method: 'put',
                url: window.location.origin + '/api/group/group_info/' + this.user.id + '/' + this.device_group[0].id,
                headers: {
                    'Accept': 'application/json',
                    'Content-Type': 'application/json',
                    'Authorization': 'Bearer ' + this.user.token
                },
                data: data
            })
                .then((response) => {
                    this.temporal_description = data.description
                    this.temporal_lat = data.lat
                    this.temporal_lng = data.lng

                    location.reload(true);

                })
                .catch((error) => {
                    window.emitter.emit('changeLoaderStatus', false, 'orbit')

                    if(error.response && error.response.status && error.response.status == 429){
                    window.alert( this.$t('text.Api attempts'));
                    }else{
                    return "Failed!", error;
                    }

                });
        },
        CancelEditLatLng() {
            document.getElementById('id_lat').value = '';
            document.getElementById('id_lng').value = '';
            this.show_latlng_buttons = false;
        },
        /*SetSector(index){
            this.temporal_sector_id = index;
            this.temporal_sector_name = this.data.group_sector[index].name;
            this.temporal_sector_tag = this.data.group_sector[index].tag;
            this.temporal_sector_description = this.data.group_sector[index].description;
            if(!this.AddSector)
                this.show_sector_buttons = false;
        },*/
        CancelEditSector() {
            document.getElementById('id_sector_name').value = '';
            document.getElementById('id_sector_tag').value = '';
            document.getElementById('id_sector_description').value = '';
            this.show_sector_buttons = false;
            this.AddSector = false;
            //this.SetSector(this.temporal_sector_id)
        },
        SaveEditSector(index) {
            var sector_name;
            if (document.getElementById('id_sector_name').value != '') {
                sector_name = document.getElementById('id_sector_name').value;
            } else {
                sector_name = this.temporal_sector_name;
            }

            var sector_tag;
            if (document.getElementById('id_sector_tag').value != '') {
                sector_tag = document.getElementById('id_sector_tag').value;
            } else {
                sector_tag = this.temporal_sector_tag;
            }

            var sector_description;
            if (document.getElementById('id_sector_description').value != '') {
                sector_description = document.getElementById('id_sector_description').value;
            } else {
                sector_description = this.temporal_sector_description;
            }

            const data = {
                name: sector_name,
                tag: sector_tag,
                description: sector_description,
            };

            window.emitter.emit('changeLoaderStatus', true, 'orbit')

            axios({
                method: 'put',
                url: window.location.origin + '/api/label/edit/sector/' + this.user.id + '/' + this.data.group_sector[index].id,
                headers: {
                    'Accept': 'application/json',
                    'Content-Type': 'application/json',
                    'Authorization': 'Bearer ' + this.user.token
                },
                data: data
            })
                .then((response) => {

                    this.data.group_sector[index].name = data.sector_name;
                    this.data.group_sector[index].tag = data.sector_tag;
                    this.data.group_sector[index].description = data.sector_description;

                    location.reload(true);

                })
                .catch((error) => {
                    window.emitter.emit('changeLoaderStatus', false, 'orbit')

                    if(error.response && error.response.status && error.response.status == 429){
                    window.alert( this.$t('text.Api attempts'));
                    }else{
                    return "Failed!", error;
                    }

                });
        },
        SetService(index) {
            this.show_service_buttons = false,
                this.temporal_service_id = index;
            this.temporal_service_name = this.data.group_service[index].name;
            this.temporal_service_tag = this.data.group_service[index].tag;
            if (document.getElementById('id_service_description')) document.getElementById('id_service_description').value = null;
            this.temporal_service_description = this.data.group_service[index].description;
        },
        SetServiceButtons() {
            if (document.getElementById('id_service_name').value != '' || document.getElementById('id_service_tag').value != '' || document.getElementById('id_service_description').value != '') {
                this.show_service_buttons = true;
            } else {
                this.show_service_buttons = false;
            }
        },
        SetSectorButtons() {
            if (document.getElementById('id_sector_name').value != '' || document.getElementById('id_sector_tag').value != '' || document.getElementById('id_sector_description').value != '') {
                this.show_sector_buttons = true;
            } else {
                if (!this.AddSector)
                    this.show_sector_buttons = false;
            }
        },
        SetLatLngButtons() {
            if (document.getElementById('id_lat').value != '' || document.getElementById('id_lng').value != '') {
                this.show_latlng_buttons = true;
            } else {
                this.show_latlng_buttons = false;
            }
        },
        SetDescriptionButtons() {
            if (document.getElementById('id_description').value != '') {
                this.show_description_buttons = true;
            } else {
                this.show_description_buttons = false;
            }
        },
        SetNameButtons() {
            if (document.getElementById('id_name').value != '') {
                this.show_name_buttons = true;
            } else {
                this.show_name_buttons = false;
            }
        },
        CancelEditService() {
            document.getElementById('id_service_name').value = '';
            document.getElementById('id_service_tag').value = '';
            document.getElementById('id_service_description').value = '';
            this.show_service_buttons = false;
            this.AddService = false;
            this.SetService(this.temporal_service_id)
        },
        SaveEditService(index) {
            var service_name;
            if (document.getElementById('id_service_name').value != '') {
                service_name = document.getElementById('id_service_name').value;
            } else {
                service_name = this.temporal_service_name;
            }

            var service_tag;
            if (document.getElementById('id_service_tag').value != '') {
                service_tag = document.getElementById('id_service_tag').value;
            } else {
                service_tag = this.temporal_service_tag;
            }

            var service_description;
            if (document.getElementById('id_service_description').value != '') {
                service_description = document.getElementById('id_service_description').value;
            } else {
                service_description = this.temporal_service_description;
            }

            var service_color = this.data.group_service[index].color;

            const data = {
                name: service_name,
                tag: service_tag,
                description: service_description,
                color: service_color,
            };

            window.emitter.emit('changeLoaderStatus', true, 'orbit')

            axios({
                method: 'put',
                url: window.location.origin + '/api/label/edit/service/' + this.user.id + '/' + this.data.group_service[index].id,
                headers: {
                    'Accept': 'application/json',
                    'Content-Type': 'application/json',
                    'Authorization': 'Bearer ' + this.user.token
                },
                data: data
            })
                .then((response) => {

                    this.data.group_service[index].name = data.service_name;
                    this.data.group_service[index].tag = data.service_tag;
                    this.data.group_service[index].description = data.service_description;
                    this.data.group_service[index].color = data.service_color;

                    location.reload(true);

                })
                .catch((error) => {
                window.emitter.emit('changeLoaderStatus', false, 'orbit')

                if(error.response && error.response.status && error.response.status == 429){
                  window.alert( this.$t('text.Api attempts'));
                }else{
                  return "Failed!", error;
                }

              });
        },
        openDelete(final_delete, selector) {
            if (final_delete && selector == 'sector') {
                this.DeleteModal = false;

                window.emitter.emit('changeLoaderStatus', true, 'orbit')

                axios({
                    method: 'delete',
                    url: window.location.origin + '/api/label/delete/sector/' + this.user.id + '/' + this.data.group_sector[this.temporal_sector_id].id,
                    headers: {
                        'Accept': 'application/json',
                        'Content-Type': 'application/json',
                        'Authorization': 'Bearer ' + this.user.token
                    },
                })
                    .then((response) => {

                        this.data.group_sector.splice(this.temporal_sector_id, 1)
                        location.reload(true);

                    })
                    .catch((error) => {
                window.emitter.emit('changeLoaderStatus', false, 'orbit')

                if(error.response && error.response.status && error.response.status == 429){
                  window.alert( this.$t('text.Api attempts'));
                }else{
                  return "Failed!", error;
                }

              });
            } else if (final_delete && selector == 'service') {
                this.DeleteModal = false;

                window.emitter.emit('changeLoaderStatus', true, 'orbit')

                axios({
                    method: 'delete',
                    url: window.location.origin + '/api/label/delete/service/' + this.user.id + '/' + this.data.group_service[this.temporal_service_id].id,
                    headers: {
                        'Accept': 'application/json',
                        'Content-Type': 'application/json',
                        'Authorization': 'Bearer ' + this.user.token
                    },
                })
                    .then((response) => {
                        this.data.group_service.splice(this.temporal_service_id, 1)
                        location.reload(true);
                    })
                    .catch((error) => {
                window.emitter.emit('changeLoaderStatus', false, 'orbit')

                if(error.response && error.response.status && error.response.status == 429){
                  window.alert( this.$t('text.Api attempts'));
                }else{
                  return "Failed!", error;
                }

              });
            } else {
                this.DeleteModal = true;
            }
            this.temporal_selector = selector;
        },

        closeDelete() {
            this.DeleteModal = false;
        },
        showCreateSector() {
            this.AddSector = true;
            this.show_sector_buttons = true;

            document.getElementById('id_sector_name').value = '';
            document.getElementById('id_sector_tag').value = '';
            document.getElementById('id_sector_description').value = '';

            this.temporal_sector_name = '';
            this.temporal_sector_tag = '';
            this.temporal_sector_description = '';
        },
        SaveCreateSector() {

            var confirmation = true;

            var sector_name;
            if (document.getElementById('id_sector_name').value != '') {
                sector_name = document.getElementById('id_sector_name').value;
            } else {
                window.emitter.emit(
                    'AppLayout_alert', 
                    true,
                    'ERROR: falta el nombre',
                    '', 
                    '18rem')
                confirmation = false;
            }

            var sector_tag;
            if (document.getElementById('id_sector_tag').value != '') {
                sector_tag = document.getElementById('id_sector_tag').value;
            } else {
                window.emitter.emit(
                    'AppLayout_alert', 
                    true,
                    'ERROR: falta el tag',
                    '', 
                    '18rem')
                confirmation = false;
            }

            var sector_description;
            if (document.getElementById('id_sector_description').value != '') {
                sector_description = document.getElementById('id_sector_description').value;
            } else {
                window.emitter.emit(
                    'AppLayout_alert', 
                    true,
                    'ERROR: falta el descripción',
                    '', 
                    '18rem')
                confirmation = false;
            }

            if (confirmation == true) {

                const data = {
                    name: sector_name,
                    tag: sector_tag,
                    description: sector_description,
                };

                window.emitter.emit('changeLoaderStatus', true, 'orbit')

                axios({
                    method: 'post',
                    url: window.location.origin + '/api/label/create/sector/' + this.user.id + '/' + this.device_group[0].id,
                    headers: {
                        'Accept': 'application/json',
                        'Content-Type': 'application/json',
                        'Authorization': 'Bearer ' + this.user.token
                    },
                    data: data
                })
                    .then((response) => {

                        this.data.group_sector.push({
                            name: data.sector_name,
                            tag: data.sector_tag,
                            description: data.sector_description
                        })

                        location.reload(true);
                    })
                    .catch((error) => {
                window.emitter.emit('changeLoaderStatus', false, 'orbit')

                if(error.response && error.response.status && error.response.status == 429){
                  window.alert( this.$t('text.Api attempts'));
                }else{
                  return "Failed!", error;
                }

              });            }

        },
        showCreateService() {
            this.AddService = true;
            this.show_service_buttons = true;

            this.temporal_service_name = '';
            this.temporal_service_tag = '';
            this.temporal_service_description = '';

            if (document.getElementById('id_service_name'))
                document.getElementById('id_service_name').value = '';

            if (document.getElementById('id_service_tag'))
                document.getElementById('id_service_tag').value = '';

            if (document.getElementById('id_service_description'))
                document.getElementById('id_service_description').value = '';
        },
        SaveCreateService() {

            var confirmation = true;

            var service_name;
            if (document.getElementById('id_service_name').value != '') {
                service_name = document.getElementById('id_service_name').value;
            } else {
                window.emitter.emit(
                    'AppLayout_alert', 
                    true,
                    'ERROR: falta el nombre',
                    '', 
                    '18rem');
                confirmation = false;
            }

            var service_tag;
            if (document.getElementById('id_service_tag').value != '') {
                service_tag = document.getElementById('id_service_tag').value;
            } else {
                window.emitter.emit(
                    'AppLayout_alert', 
                    true,
                    'ERROR: falta el tag',
                    '', 
                    '18rem')
                confirmation = false;
            }

            var service_description;
            if (document.getElementById('id_service_description').value != '') {
                service_description = document.getElementById('id_service_description').value;
            } else {
                window.emitter.emit(
                    'AppLayout_alert', 
                    true,
                    'ERROR: falta el descripción',
                    '', 
                    '18rem')
                confirmation = false;
            }

            if (confirmation == true) {
                const service_color = this.Random_color()

                const data = {
                    name: service_name,
                    tag: service_tag,
                    description: service_description,
                    color: service_color,
                };

                window.emitter.emit('changeLoaderStatus', true, 'orbit')

                axios({
                    method: 'post',
                    url: window.location.origin + '/api/label/create/service/' + this.user.id + '/' + this.device_group[0].id,
                    headers: {
                        'Accept': 'application/json',
                        'Content-Type': 'application/json',
                        'Authorization': 'Bearer ' + this.user.token
                    },
                    data: data
                })
                    .then((response) => {

                        this.data.group_service.push({
                            name: data.service_name,
                            tag: data.service_tag,
                            color: data.service_color,
                            description: data.service_description
                        })

                        location.reload(true);

                    })
                    .catch((error) => {
                window.emitter.emit('changeLoaderStatus', false, 'orbit')

                if(error.response && error.response.status && error.response.status == 429){
                  window.alert( this.$t('text.Api attempts'));
                }else{
                  return "Failed!", error;
                }

              });            }

        },

        Random_color() {
            let hex = new Array("0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "A", "B", "C", "D", "E", "F")
            let rand_color = "#";
            for (var i = 0; i < 6; i++) {
                let array_index = this.rand(0, hex.length)
                rand_color += hex[array_index]
            }
            return rand_color;
        },

        rand(min_limit, max_limit) {
            let pool = max_limit - min_limit
            let aleat = Math.random() * pool
            aleat = Math.floor(aleat)
            return parseInt(min_limit) + aleat
        },

        tagItem: function (item) {
        },

        selectItem: function (item) {


            /*this.temporal_sector_id = item.id;
            this.temporal_sector_name = item.name;
            this.temporal_sector_tag = item.tag;
            this.temporal_sector_description = item.description;
            if(!this.AddSector)
                this.show_sector_buttons = false;*/

        },

        removeItem: function (item) {
        },

        closeMultiselect: function (item) {

            let value_selector = this.value_selector;
            let temporal_sector_id = this.temporal_sector_id;

            this.data.group_sector.forEach(function callback(sector, index) {
                if (sector.id == value_selector.id) {
                    temporal_sector_id = index
                }
            });

            this.temporal_sector_id = temporal_sector_id;

            this.temporal_sector_name = value_selector.name;
            this.temporal_sector_tag = value_selector.tag;
            this.temporal_sector_description = value_selector.description;
            if (!this.AddSector)
                this.show_sector_buttons = false;

        },

        openMultiselect: function (item) {
        },

        scMultiselect: function (item) {
        },

        inputMultiselect: function (item) {

        },
    },
}    
</script>
